<?php

namespace Litecms\BusesCategory\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\BusesCategory\Interfaces\BusesCategoryRepositoryInterface;

class BusesCategoryPublicController extends BaseController
{
    // use BusesCategoryWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\BusesCategory\Interfaces\BusesCategoryRepositoryInterface $buses_category
     *
     * @return type
     */
    public function __construct(BusesCategoryRepositoryInterface $buses_category)
    {
        $this->repository = $buses_category;
        parent::__construct();
    }

    /**
     * Show buses_category's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $buses_categories = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$buses_category::$buses_category.names'))
            ->view('$buses_category::public.buses_category.index')
            ->data(compact('$buses_categories'))
            ->output();
    }

    /**
     * Show buses_category's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $buses_categories = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$buses_category::$buses_category.names'))
            ->view('$buses_category::public.buses_category.index')
            ->data(compact('$buses_categories'))
            ->output();
    }

    /**
     * Show buses_category.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $buses_category = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$buses_category->name . trans('$buses_category::$buses_category.name'))
            ->view('$buses_category::public.buses_category.show')
            ->data(compact('$buses_category'))
            ->output();
    }

}
