<?php

namespace Litecms\BusesCategory\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\BusesCategory\Models\BusesCategory;

class BusesCategoryPolicy
{

    /**
     * Determine if the given user can view the buses_category.
     *
     * @param UserPolicy $user
     * @param BusesCategory $buses_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, BusesCategory $buses_category)
    {
        if ($user->canDo('buses_category.buses_category.view') && $user->isAdmin()) {
            return true;
        }

        return $buses_category->user_id == user_id() && $buses_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a buses_category.
     *
     * @param UserPolicy $user
     * @param BusesCategory $buses_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('buses_category.buses_category.create');
    }

    /**
     * Determine if the given user can update the given buses_category.
     *
     * @param UserPolicy $user
     * @param BusesCategory $buses_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, BusesCategory $buses_category)
    {
        if ($user->canDo('buses_category.buses_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $buses_category->user_id == user_id() && $buses_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given buses_category.
     *
     * @param UserPolicy $user
     * @param BusesCategory $buses_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BusesCategory $buses_category)
    {
        return $buses_category->user_id == user_id() && $buses_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given buses_category.
     *
     * @param UserPolicy $user
     * @param BusesCategory $buses_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BusesCategory $buses_category)
    {
        if ($user->canDo('buses_category.buses_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given buses_category.
     *
     * @param UserPolicy $user
     * @param BusesCategory $buses_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BusesCategory $buses_category)
    {
        if ($user->canDo('buses_category.buses_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
